/**
  ********************************(C) COPYRIGHT 2017 DJI************************
  * @file       gimbal_task.h
	* @brief      basic gimbal control and autoshoot task
	* @update	        
	*	@history
	* Version     Date          Author           Modification
  * V1.0.0      Apr-30-2017   Richard.luo 
  * @verbatim
	* yaw axis  : angle feedback is single axis gyro, palstance feedback is mpu6500 gyro
	* pitch axis: angle feedback is encoder, palstance feedback is mpu6500 gyro
	********************************(C) COPYRIGHT 2017 DJI************************
	*/

#ifndef __GIMBAL_TASK_H__
#define __GIMBAL_TASK_H__

#include "mytype.h"
void gimbal_task(const void* argu);

typedef enum {

    GIMBAL_INIT = 0,
    GIMBAL_RELAX,
    //GIMBAL_CLOSE_LOOP_ENCODER,
	
		GIMBAL_AUTO_SHOOT,
    GIMBAL_CLOSE_LOOP_ZGYRO,
		GIMBAL_SEARCH_TARGET,

} eGimbalMode;

typedef enum {

    CONTINUE_MODE = 0,
    KA_DAN_MODE,

} eTriggerMode;

typedef struct
{
    eGimbalMode ctrl_mode; //yaw
    eGimbalMode last_mode; //

    float zgyro_target;
   	//float zgyro_rc;
   	//float zgyro_mouse;
    float zgyro_angle;
    float zgyro_offset;
		eTriggerMode	trigger_mode;
		

} gimbal_yaw_t;

typedef struct{

	float Q;
	float R;
	float Zmeasure;
	float p_mid;
	float p_now;
	float p_last;
	float x_mid;
	float x_last;
	float x_now;
	float v_diff;

}KLM_Fliter;

extern KLM_Fliter visionX_klm_fliter;
extern KLM_Fliter visionY_klm_fliter;
extern KLM_Fliter visionD_klm_fliter;

extern gimbal_yaw_t      gYaw;
extern s16   yaw_relative_pos;
extern float pit_relative_angle;
extern float yaw_relative_angle;
extern int   auto_chassis_follow_gim;
extern float search_begin_time;
extern int   auto_shoot_cmd;
extern int   need_move_cmd;
extern int   aim_ok_flag;


extern float M1[3][4];

extern float M2[4][4];

#define FX M1[0][0]
#define FY M1[1][1]
#define CX M1[0][2]
#define CY M1[1][2]
#define Y_DISTANCE M2[1][3]

#endif
